'use strict';

const {reportError} = require('../../../core/utils');
const {knex} = require('../../../models');

module.exports = async (req, res) => {
    const wiki = req.query.wiki;

    try {
        if (!wiki) {
            res.status(400).send('Wiki name is required');
            return;
        }
        const result = await knex.raw(
            `
                SELECT DISTINCT unnest(tags) AS tag
                FROM wikidot_pages
                WHERE wiki_name = ?;`,
            [wiki]
        );
        const tags = result.rows.map(row => row.tag);
        res.send(tags.sort((one, another) => one.localeCompare(another)));
    } catch (error) {
        res.status(500).send('Unhandled internal error, incident reported');
        reportError(error, {tags: {location: 'wikidot/tags-list'}});
    }
};
