'use strict';

const {reportError} = require('../../../core/utils');
const {knex} = require('../../../models');

module.exports = async (req, res) => {
    const wiki = req.query.wiki;
    const tags = Array.isArray(req.query.tag) ? req.query.tag : [req.query.tag];

    if (wiki && tags) {
        try {
            const result = await knex.raw(`
                SELECT id, name, title, tags as all_tags
                FROM wikidot_pages
                WHERE wiki_name = ? AND ? :: TEXT [] <@ tags;
            `, [wiki, tags]);

            res.send(result.rows);
        } catch (error) {
            res.status(500).send('Unhandled internal error, incident reported');
            reportError(error, {tags: {location: 'wikidot/tags-search'}});
        }
    } else {
        res.status(400).send({error: 'Wiki or tags are not specified'});
    }
};
