'use strict';

const pino = require('./pino');
const sentry = require('./sentry');
const redis = require('redis').createClient();
const {CommonQueue} = require('../components/queues');

const log = exports.log = function (message, args) {
    if (args) {
        pino.info(args, message);
    } else {
        pino.info(message);
    }
};

exports.reportError = function (error, args) {
    const callArgs = [error];
    if (args) {
        if (args.message) {
            callArgs.push(args.message);
        }
        if (args.extra) {
            callArgs.push(args.extra);
        }
    }
    pino.error.apply(pino, callArgs);
    sentry.captureException(error, args);
};

exports.enqueue = function (task, args) {
    return CommonQueue.add({task, args});
};

exports.logToDiscord = function (message) {
    log(`[DiscordLogger] ${message}`);
    redis.publish('discordLog', message);
};
