'use strict';

const {logToDiscord, reportError} = require('../core/utils');
const Discord = require('discord.js');
const {WikidotUser} = require('../models');
const discord = new Discord.Client();
const token = process.env.DISCORD_BOT_TOKEN;

const SCP_RU_GUILD_ID = '106464299056128000';
const MEMBERS_ROLE_ID = '106465861476319232';

module.exports = function run() {
    return new Promise((resolve) => {
        discord.on('ready', () => {
            const guild = discord.guilds.find((data, key) => key === SCP_RU_GUILD_ID);
            const memberRole = guild.roles.find((role) => {
                return role.id === MEMBERS_ROLE_ID;
            });

            logToDiscord('Initiating Discord roles sync');

            let numberOfMembersToSync;
            WikidotUser.membersWithDiscordTag()
                .then((memberDiscordIDs) => {
                    const usersToUpdate = guild.members.filterArray(member => {
                        const user = member.user;
                        const userId = `${user.username}#${user.discriminator}`;
                        return memberDiscordIDs.includes(userId) && !member.roles.has(MEMBERS_ROLE_ID);
                    });
                    numberOfMembersToSync = usersToUpdate.length;
                    if (numberOfMembersToSync) {
                        logToDiscord(`Adding roles: ${numberOfMembersToSync}`);
                    } else {
                        logToDiscord('Everything is in sync');
                    }
                    return usersToUpdate;
                })
                .map(userToUpdate => {
                    logToDiscord(`Adding role to user \`${userToUpdate.user.username}\``);
                    return userToUpdate.addRole(memberRole);
                })
                .then(() => {
                    if (numberOfMembersToSync) {
                        logToDiscord(`Synced discord roles for ${numberOfMembersToSync} user(s)`);
                    }
                    resolve();
                })
                .catch(error => {
                    reportError(error, {message: 'Error setting discord member roles'});
                    resolve();
                });
        });
        discord.login(token);
    });
};
