'use strict';

const {WikidotUser} = require('../models');
const {log, reportError} = require('../core/utils');
const {wk, SITES} = require('../components/wikidot-kit');

module.exports = function run(siteName, uid) {
    const wiki = SITES[siteName];
    log(`Importing member ${uid} from ${wiki.name}`);

    return wk.fetchUserProfile(wiki.url, uid)
        .then(user => {
            log('Imported user profile', user);
            return WikidotUser.upsert({
                uid: user.uid,
                username: user.username,
                regDate: user.userSince,
                about: user.about,
                memberships: {[siteName]: user.memberSince}
            });
        })
        .catch(error => {
            reportError(error, {message: 'Error importing member profile', extra: {uid}});
        });
};
